#ifndef POKEPLATINUM_UNK_02020020_H
#define POKEPLATINUM_UNK_02020020_H

#include "struct_decls/struct_020203AC_decl.h"
#include "overlay115/struct_ov115_0226527C.h"

#include <nitro/fx/fx.h>

void sub_02020304(const int param0, const int param1, const int param2, const int param3, UnkStruct_020203AC * param4);
void sub_02020390(UnkStruct_020203AC * param0);
UnkStruct_020203AC * sub_020203AC(const int param0);
void sub_020203B8(UnkStruct_020203AC * param0);
void sub_020203C0(UnkStruct_020203AC const * param0, UnkStruct_020203AC * param1);
void sub_020203D4(UnkStruct_020203AC * param0);
void sub_020203E0(void);
void sub_020203EC();
void sub_0202049C(void);
void sub_02020680(const VecFx32 * param0, UnkStruct_020203AC * param1);
void sub_02020690(const VecFx32 * param0, UnkStruct_020203AC * param1);
void sub_020206B0(UnkStruct_020203AC * param0);
void sub_020206BC(const fx32 param0, const fx32 param1, UnkStruct_020203AC * param2);
void sub_020206D0(const VecFx32 * param0, const fx32 param1, const UnkStruct_ov115_0226527C * param2, const u16 param3, const u8 param4, const BOOL param5, UnkStruct_020203AC * param6);
void sub_02020738(const VecFx32 * param0, const fx32 param1, const UnkStruct_ov115_0226527C * param2, const u16 param3, const u8 param4, UnkStruct_020203AC * param5);
void sub_02020784(const VecFx32 * param0, const VecFx32 * param1, const u16 param2, const u8 param3, const BOOL param4, UnkStruct_020203AC * param5);
void sub_02020854(const u8 param0, UnkStruct_020203AC * param1);
void sub_02020910(const u16 param0, UnkStruct_020203AC * param1);
void sub_0202094C(const u16 param0, UnkStruct_020203AC * param1);
void sub_02020990(const VecFx32 * param0, UnkStruct_020203AC * param1);
void sub_020209B0(const UnkStruct_ov115_0226527C * param0, UnkStruct_020203AC * param1);
void sub_020209D4(const UnkStruct_ov115_0226527C * param0, UnkStruct_020203AC * param1);
void sub_020209F8(const UnkStruct_ov115_0226527C * param0, UnkStruct_020203AC * param1);
void sub_02020A24(const UnkStruct_ov115_0226527C * param0, UnkStruct_020203AC * param1);
void sub_02020A50(const fx32 param0, UnkStruct_020203AC * param1);
void sub_02020A5C(const VecFx32 * param0, UnkStruct_020203AC * param1);
void sub_02020A78(const fx32 param0, UnkStruct_020203AC * param1);
u16 sub_02020A88(UnkStruct_020203AC const * param0);
fx32 sub_02020A90(UnkStruct_020203AC const * param0);
UnkStruct_ov115_0226527C sub_02020A94(UnkStruct_020203AC const * param0);
VecFx32 sub_02020AAC(UnkStruct_020203AC const * param0);
VecFx32 sub_02020ABC(UnkStruct_020203AC const * param0);
void sub_02020ACC(const VecFx32 * param0, UnkStruct_020203AC * param1);
void sub_02020ADC(const VecFx32 * param0, UnkStruct_020203AC * param1);

#endif // POKEPLATINUM_UNK_02020020_H
